==> marble_16.04.3.orig.tar.xz: marble-16.04.3/src/lib/marble/geodata/handlers/kml/KmlIconTagHandler.cpp <==
/*
    Copyright (C) 2008 Patrick Spendrin <ps_ml@gmx.de>

    This file is part of the KDE project

    This library is free software you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    aint with this library see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#include "KmlIconTagHandler.h"

#include "MarbleDebug.h"

#include "KmlElementDictionary.h"
#include "GeoDataIconStyle.h"
#include "GeoDataGroundOverlay.h"
#include "GeoDataPhotoOverlay.h"
#include "GeoDataScreenOverlay.h"
#include "GeoParser.h"

namespace Marble
{
namespace kml
{
KML_DEFINE_TAG_HANDLER( Icon )

GeoNode* KmlIconTagHandler::parse( GeoParser& parser ) const
{
    Q_ASSERT( parser.isStartElement() && parser.isValidElement( kmlTag_Icon ) );

    GeoStackItem parentItem = parser.parentElement();
    
    if ( parentItem.represents( kmlTag_IconStyle ) ) {
        return parentItem.nodeAs<GeoDataIconStyle>();
    } else if ( parentItem.represents( kmlTag_GroundOverlay ) ) {
        return parentItem.nodeAs<GeoDataGroundOverlay>();
    }  else if ( parentItem.represents( kmlTag_PhotoOverlay ) ) {
        return parentItem.nodeAs<GeoDataPhotoOverlay>();
    }  else if ( parentItem.represents( kmlTag_ScreenOverlay ) ) {
        return parentItem.nodeAs<GeoDataScreenOverlay>();
    }
    return 0;
}

}
}

==> marble-17.04.3.tar.xz: marble-17.04.3/src/lib/marble/geodata/handlers/kml/KmlIconTagHandler.cpp <==
/*
    Copyright (C) 2008 Patrick Spendrin <ps_ml@gmx.de>

    This file is part of the KDE project

    This library is free software you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    aint with this library see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#include "KmlIconTagHandler.h"

#include "MarbleDebug.h"

#include "KmlElementDictionary.h"
#include "GeoDataIconStyle.h"
#include "GeoDataGroundOverlay.h"
#include "GeoDataPhotoOverlay.h"
#include "GeoDataScreenOverlay.h"
#include "GeoParser.h"

namespace Marble
{
namespace kml
{
KML_DEFINE_TAG_HANDLER( Icon )

GeoNode* KmlIconTagHandler::parse( GeoParser& parser ) const
{
    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_Icon)));

    GeoStackItem parentItem = parser.parentElement();
    
    if ( parentItem.represents( kmlTag_IconStyle ) ) {
        return parentItem.nodeAs<GeoDataIconStyle>();
    } else if ( parentItem.represents( kmlTag_GroundOverlay ) ) {
        return parentItem.nodeAs<GeoDataGroundOverlay>();
    }  else if ( parentItem.represents( kmlTag_PhotoOverlay ) ) {
        return parentItem.nodeAs<GeoDataPhotoOverlay>();
    }  else if ( parentItem.represents( kmlTag_ScreenOverlay ) ) {
        return parentItem.nodeAs<GeoDataScreenOverlay>();
    }
    return 0;
}

}
}
